@@ -142,7 +142,7 @@ def download_layer(layer, output_file, plot=False, no_save=False):
         except ImportError as e:
             # import traceback
             # traceback.print_exc()
-            print(f"\n\n  WARN: {e}. \n  To use the --plot option you need to install the following packages: geopandas, descartes, matplotlib. \n  For example, use:  pip install -y geopandas descartes matplotlib")
+            print(f"\n\n  WARN: {e}. \n  To use the --plot option you need to install the following packages: geopandas, descartes, matplotlib. \n  For example, use:  pip install geopandas descartes matplotlib")
 
 
 def list_health():
